Struct nitro::input::Axis [] [src]

pub struct Axis { /* fields omitted */ }

An input axis, could be bound to W and S, A and D, up and down, or left and right.

Methods

impl Axis
[src]

[src]

[src]